@@ -1,16 +1,15 @@
+import logging
 import multiprocessing as mp
-import os
 import socket
 import threading
 from queue import Queue
 
-import simdjson as json
-
 from .helpers import *
-import logging
 
 
-class DataFrameClient:
+class DataFrameClient():
+    # TODO: add 'del' operation
+
     def __init__(self, pool, conn):
         self.pool = pool
         self.conn = conn
@@ -21,15 +20,24 @@ class DataFrameClient:
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.pool.release_connection(self.conn)
 
-    def get_data(self, *args, range_start=None, range_end=None, range_type="timestamp"):
-        send_cmd(self.conn, 'get', key_path=args, range_start=range_start, range_end=range_end, range_type=range_type)
+    def filter(self, *args, range_start=None, range_end=None, range_type="timestamp"):
+        send_cmd(self.conn, 'df:filter', key_path=args, range_start=range_start, range_end=range_end, range_type=range_type, namespace=namespace)
         return recv_df(self.conn)
 
-    def insert_data(self, df, *args):
-        send_cmd(self.conn, 'insert', key_path=args)
+    def update(self, df, *args):
+        send_cmd(self.conn, 'df:update', key_path=args)
         send_df(self.conn, df)
         recv_status(self.conn)
 
+    def get(self, *args):
+        send_cmd(self.conn, 'get', key_path=args)
+        return recv_msg(self.conn)
+
+    def set(self, contents, *args):
+       send_cmd(self.conn, 'set', key_path=args)
+       send_msg(self.conn, contents)
+       recv_status(self.conn)
+
     def unload(self, *args):
         send_cmd(self.conn, 'unload', key_path=args)
         recv_status(self.conn)
@@ -39,7 +47,7 @@ class DataFrameClient:
         return recv_json(self.conn)
 
     def get_stats(self, level=None):
-        send_msg(self.conn, json.dumps({'type': 'stats', 'level': level}).encode())
+        send_cmd(self.conn, 'stats', level=level)
         return recv_json(self.conn)
 
 
@@ -89,7 +97,7 @@ class DataFrameConnectionPool:
             conn = None
             try:
                 conn = self.connections.get()
-                send_msg(conn, json.dumps({'type': 'close'}).encode())
+                send_cmd(conn, 'close')
                 recv_msg(conn)
             except Exception:
                 pass
